==> kmymoney_5.1.2.orig.tar.xz: kmymoney-5.1.2/kmymoney/plugins/views/forecast/forecastview.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "asoliverez@gmail.com,lukasz.wojnilowicz@gmail.com",
                "Name": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ca@valencia]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ca]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[cs]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[de]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[en_GB]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[es]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[et]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[eu]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[fi]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[fr]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[gl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ia]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[it]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ko]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[nl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pt]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ru]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sk]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sv]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[uk]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[x-test]": "xxAlvaro Soliverez,Łukasz Wojniłowiczxx",
                "Name[zh_CN]": "Alvaro Soliverez,Łukasz Wojniłowicz"
            }
        ],
        "Description": "Adds forecast view to KMyMoney",
        "Description[ca@valencia]": "Afig la vista de la previsió al KMyMoney",
        "Description[ca]": "Afegeix la vista de la previsió al KMyMoney",
        "Description[en_GB]": "Adds forecast view to KMyMoney",
        "Description[es]": "Añade la vista de pronósticos a KMyMoney",
        "Description[et]": "KMyMoney ennustusvaade",
        "Description[eu]": "Aurreikuspen ikuspegia gehitzen dio KMyMoneyri",
        "Description[fi]": "Lisää KMyMoneyyn ennustenäkymän",
        "Description[fr]": "Ajoute la vue Prévisions à KMyMoney",
        "Description[gl]": "Engade unha vista de prognóstico a KMyMoney",
        "Description[it]": "Aggiunge la vista delle previsioni a KMyMoney",
        "Description[ko]": "KMyMoney에 예측 보기 추가",
        "Description[nl]": "Voegt weergave van prognoses toe aan KMyMoney",
        "Description[pl]": "Dodaje widok prognoz do KMyMoney",
        "Description[pt]": "Adiciona a área de antevisão ao KMyMoney",
        "Description[pt_BR]": "Adiciona área de previsão no KMyMoney",
        "Description[sk]": "Pridá pohľad predpovede do KMyMoney",
        "Description[sl]": "Doda pogled napovedi v KMyMoney",
        "Description[sv]": "Lägger till prognosvy i KMyMoney",
        "Description[uk]": "Панель прогнозів у KMyMoney",
        "Description[x-test]": "xxAdds forecast view to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加预测视图",
        "EnabledByDefault": true,
        "Icon": "forecast",
        "Id": "forecastview",
        "License": "GPL",
        "Name": "Forecast view",
        "Name[ca@valencia]": "Vista de la previsió",
        "Name[ca]": "Vista de la previsió",
        "Name[de]": "Vorhersageansicht",
        "Name[en_GB]": "Forecast view",
        "Name[es]": "Vista del pronóstico",
        "Name[et]": "Ennustusvaade",
        "Name[eu]": "Aurreikuspen ikuspegia",
        "Name[fi]": "Ennustenäkymä",
        "Name[fr]": "Vue Prévisions",
        "Name[gl]": "Vista de prognóstico",
        "Name[ia]": "Vista de prevision",
        "Name[it]": "Vista delle previsioni",
        "Name[ko]": "예측 보기",
        "Name[nl]": "Prognoseweergave",
        "Name[pl]": "Widok prognozy",
        "Name[pt]": "Área de Previsão",
        "Name[pt_BR]": "Área de previsão",
        "Name[sk]": "Pohľad predpovede",
        "Name[sl]": "Pogled napovedi",
        "Name[sv]": "Prognosvy",
        "Name[uk]": "Перегляд прогнозів",
        "Name[x-test]": "xxForecast viewxx",
        "Name[zh_CN]": "预测视图",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney-5.1.90.tar.xz: kmymoney-5.1.90/kmymoney/plugins/views/forecast/forecastview.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "asoliverez@gmail.com,lukasz.wojnilowicz@gmail.com",
                "Name": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ca@valencia]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ca]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[cs]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[de]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[en_GB]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[eo]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[es]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[et]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[eu]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[fi]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[fr]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[gl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ia]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[it]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ka]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ko]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[nb]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[nl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pt]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ru]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sk]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sv]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[tr]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[uk]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[x-test]": "xxAlvaro Soliverez,Łukasz Wojniłowiczxx",
                "Name[zh_CN]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[zh_TW]": "Alvaro Soliverez、Łukasz Wojniłowicz"
            }
        ],
        "Description": "Adds forecast view to KMyMoney",
        "Description[ca@valencia]": "Afig la vista de la previsió a KMyMoney",
        "Description[ca]": "Afegeix la vista de la previsió al KMyMoney",
        "Description[en_GB]": "Adds forecast view to KMyMoney",
        "Description[eo]": "Aldonas prognozan vidon al KMyMoney",
        "Description[es]": "Añade la vista de pronósticos a KMyMoney",
        "Description[et]": "KMyMoney ennustusvaade",
        "Description[eu]": "Aurreikuspen ikuspegia gehitzen dio KMyMoneyri",
        "Description[fi]": "Lisää KMyMoneyyn ennustenäkymän",
        "Description[fr]": "Ajoute la vue Prévisions à KMyMoney",
        "Description[gl]": "Engade unha vista de prognóstico a KMyMoney",
        "Description[it]": "Aggiunge la vista delle previsioni a KMyMoney",
        "Description[ka]": "KMyMoney-ში პროგნოზის ხედის დამატება",
        "Description[ko]": "KMyMoney에 예측 보기 추가",
        "Description[nb]": "Legger til prognosevisning i KMyMoney",
        "Description[nl]": "Voegt weergave van prognoses toe aan KMyMoney",
        "Description[pl]": "Dodaje widok prognoz do KMyMoney",
        "Description[pt]": "Adiciona a área de antevisão ao KMyMoney",
        "Description[pt_BR]": "Adiciona área de previsão no KMyMoney",
        "Description[ru]": "Добавляет в KMyMoney представление прогнозов",
        "Description[sk]": "Pridá pohľad predpovede do KMyMoney",
        "Description[sl]": "Doda pogled napovedi v KMyMoney",
        "Description[sv]": "Lägger till prognosvy i KMyMoney",
        "Description[tr]": "K Param'a öngörü görünümü ekler",
        "Description[uk]": "Панель прогнозів у KMyMoney",
        "Description[x-test]": "xxAdds forecast view to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加预测视图",
        "Description[zh_TW]": "提供預測檢視給 KMyMoney",
        "EnabledByDefault": true,
        "Icon": "forecast",
        "Id": "forecastview",
        "License": "GPL",
        "Name": "Forecast view",
        "Name[ca@valencia]": "Vista de la previsió",
        "Name[ca]": "Vista de la previsió",
        "Name[de]": "Vorhersageansicht",
        "Name[en_GB]": "Forecast view",
        "Name[eo]": "Prognozo-vido",
        "Name[es]": "Vista del pronóstico",
        "Name[et]": "Ennustusvaade",
        "Name[eu]": "Aurreikuspen ikuspegia",
        "Name[fi]": "Ennustenäkymä",
        "Name[fr]": "Vue Prévisions",
        "Name[gl]": "Vista de prognóstico",
        "Name[ia]": "Vista de prevision",
        "Name[it]": "Vista delle previsioni",
        "Name[ka]": "პროგნოზის ხედი",
        "Name[ko]": "예측 보기",
        "Name[nb]": "Prognosevisning",
        "Name[nl]": "Prognoseweergave",
        "Name[pl]": "Widok prognozy",
        "Name[pt]": "Área de Previsão",
        "Name[pt_BR]": "Área de previsão",
        "Name[ru]": "Представление прогнозов",
        "Name[sk]": "Pohľad predpovede",
        "Name[sl]": "Pogled napovedi",
        "Name[sv]": "Prognosvy",
        "Name[tr]": "Öngörü Görünümü",
        "Name[uk]": "Перегляд прогнозів",
        "Name[x-test]": "xxForecast viewxx",
        "Name[zh_CN]": "预测视图",
        "Name[zh_TW]": "預測檢視",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    },
    "X-KDE-ConfigModule": "kmymoney_plugins/kcms/kcm_forecastview"
}
